@@ -21,16 +21,12 @@ import os
 
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
 
 from taskflow import exceptions as exc
-from taskflow import logging
 from taskflow import states
 from taskflow.types import failure as ft
 from taskflow.utils import misc
 
-LOG = logging.getLogger(__name__)
-
 
 # Internal helpers...
 
@@ -153,11 +149,11 @@ class LogBook(object):
         if self.created_at is not None:
             lines.append("%s- created_at = %s"
                          % (" " * (indent + 1),
-                            timeutils.isotime(self.created_at)))
+                            self.created_at.isoformat()))
         if self.updated_at is not None:
             lines.append("%s- updated_at = %s"
                          % (" " * (indent + 1),
-                            timeutils.isotime(self.updated_at)))
+                            self.updated_at.isoformat()))
         for flow_detail in self:
             lines.append(flow_detail.pformat(indent=indent + 1,
                                              linesep=linesep))
@@ -262,7 +258,7 @@ class LogBook(object):
         return self._name
 
     def __iter__(self):
-        for fd in six.itervalues(self._flowdetails_by_id):
+        for fd in self._flowdetails_by_id.values():
             yield fd
 
     def __len__(self):
@@ -304,13 +300,15 @@ class FlowDetail(object):
     guaranteed to be persisted when a save (or update) occurs via some backend
     connection.
 
-    :ivar state: The state of the flow associated with this flow detail.
     :ivar meta: A dictionary of meta-data associated with this flow detail.
     """
     def __init__(self, name, uuid):
         self._uuid = uuid
         self._name = name
         self._atomdetails_by_id = {}
+        # TODO(bnemec): This should be documented as an ivar, but can't be due
+        # to https://github.com/sphinx-doc/sphinx/issues/2549
+        #: The state of the flow associated with this flow detail.
         self.state = None
         self.meta = {}
 
@@ -465,15 +463,14 @@ class FlowDetail(object):
         return self._name
 
     def __iter__(self):
-        for ad in six.itervalues(self._atomdetails_by_id):
+        for ad in self._atomdetails_by_id.values():
             yield ad
 
     def __len__(self):
         return len(self._atomdetails_by_id)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AtomDetail(object):
+class AtomDetail(object, metaclass=abc.ABCMeta):
     """A collection of atom specific runtime information and metadata.
 
     This is a base **abstract** class that contains attributes that are used
@@ -489,7 +486,6 @@ class AtomDetail(object):
     guaranteed to be persisted when a save (or update) occurs via some backend
     connection.
 
-    :ivar state: The state of the atom associated with this atom detail.
     :ivar intention: The execution strategy of the atom associated
                      with this atom detail (used by an engine/others to
                      determine if the associated atom needs to be
@@ -503,7 +499,7 @@ class AtomDetail(object):
                    ``execute`` method or from other sources.
     :ivar revert_results: Any results the atom produced from either its
                           ``revert`` method or from other sources.
-    :ivar failure: If the atom failed (due to its ``execute`` method
+    :ivar AtomDetail.failure: If the atom failed (due to its ``execute`` method
                    raising) this will be a
                    :py:class:`~taskflow.types.failure.Failure` object that
                    represents that failure (if there was no failure this
@@ -518,6 +514,9 @@ class AtomDetail(object):
     def __init__(self, name, uuid):
         self._uuid = uuid
         self._name = name
+        # TODO(bnemec): This should be documented as an ivar, but can't be due
+        # to https://github.com/sphinx-doc/sphinx/issues/2549
+        #: The state of the atom associated with this atom detail.
         self.state = None
         self.intention = states.EXECUTE
         self.results = None
@@ -704,7 +703,7 @@ class AtomDetail(object):
 class TaskDetail(AtomDetail):
     """A task detail (an atom detail typically associated with a |tt| atom).
 
-    .. |tt| replace:: :py:class:`~taskflow.task.BaseTask`
+    .. |tt| replace:: :py:class:`~taskflow.task.Task`
     """
 
     def reset(self, state):
@@ -886,7 +885,7 @@ class RetryDetail(AtomDetail):
         # contain tracebacks, which are not copyable.
         for (data, failures) in self.results:
             copied_failures = {}
-            for (key, failure) in six.iteritems(failures):
+            for (key, failure) in failures.items():
                 copied_failures[key] = failure
             results.append((data, copied_failures))
         clone.results = results
@@ -979,7 +978,7 @@ class RetryDetail(AtomDetail):
             new_results = []
             for (data, failures) in results:
                 new_failures = {}
-                for (key, data) in six.iteritems(failures):
+                for (key, data) in failures.items():
                     new_failures[key] = ft.Failure.from_dict(data)
                 new_results.append((data, new_failures))
             return new_results
@@ -997,7 +996,7 @@ class RetryDetail(AtomDetail):
             new_results = []
             for (data, failures) in results:
                 new_failures = {}
-                for (key, failure) in six.iteritems(failures):
+                for (key, failure) in failures.items():
                     new_failures[key] = failure.to_dict()
                 new_results.append((data, new_failures))
             return new_results
@@ -1040,7 +1039,7 @@ class RetryDetail(AtomDetail):
         # contain tracebacks, which are not copyable.
         for (data, failures) in other.results:
             copied_failures = {}
-            for (key, failure) in six.iteritems(failures):
+            for (key, failure) in failures.items():
                 if deep_copy:
                     copied_failures[key] = failure.copy()
                 else:
@@ -1055,8 +1054,8 @@ _DETAIL_TO_NAME = {
     TaskDetail: 'TASK_DETAIL',
 }
 _NAME_TO_DETAIL = dict((name, cls)
-                       for (cls, name) in six.iteritems(_DETAIL_TO_NAME))
-ATOM_TYPES = list(six.iterkeys(_NAME_TO_DETAIL))
+                       for (cls, name) in _DETAIL_TO_NAME.items())
+ATOM_TYPES = list(_NAME_TO_DETAIL.keys())
 
 
 def atom_detail_class(atom_type):
